==> hvcg_academics_openapi_student-0.1.0.crate: hvcg_academics_openapi_student-0.1.0/docs/student_mutation_api.md <==
# student_mutation_api

All URIs are relative to *https://dev-sg.portal.hocvienconggiao.com*

Method | HTTP request | Description
------------- | ------------- | -------------
**addstudent**](student_mutation_api.md#addstudent) | **POST** /mutation-api/student-service/students | Add new student
**update_student**](student_mutation_api.md#update_student) | **PUT** /mutation-api/student-service/students/{id} | Update an existing student


# **addstudent**
> models::Student addstudent(ctx, student)
Add new student

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **student** | [**Student**](Student.md)| student object that needs to be added to the database | 

### Return type

[**models::Student**](Student.md)

### Authorization

[student_auth](../README.md#student_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_student**
> models::Student update_student(ctx, id, student)
Update an existing student

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| ID of student to update | 
  **student** | [**Student**](Student.md)| student object that needs to be added to the database | 

### Return type

[**models::Student**](Student.md)

### Authorization

[student_auth](../README.md#student_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> hvcg_academics_openapi_student-0.2.1.crate: hvcg_academics_openapi_student-0.2.1/docs/student_mutation_api.md <==
# student_mutation_api

All URIs are relative to *https://dev-sg.portal.hocvienconggiao.com*

Method | HTTP request | Description
------------- | ------------- | -------------
**addStudent**](student_mutation_api.md#addStudent) | **POST** /mutation-api/student-service/students | Add new student
**deleteStudent**](student_mutation_api.md#deleteStudent) | **DELETE** /mutation-api/student-service/students/{id} | Deletes a student
**updateStudent**](student_mutation_api.md#updateStudent) | **PUT** /mutation-api/student-service/students/{id} | Update an existing student


# **addStudent**
> models::Student addStudent(ctx, student)
Add new student

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **student** | [**Student**](Student.md)| student object that needs to be added to the database | 

### Return type

[**models::Student**](Student.md)

### Authorization

[student_auth](../README.md#student_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteStudent**
> deleteStudent(ctx, id)
Deletes a student

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| ID of student to delete | 

### Return type

 (empty response body)

### Authorization

[student_auth](../README.md#student_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateStudent**
> models::Student updateStudent(ctx, id, student)
Update an existing student

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| ID of student to update | 
  **student** | [**Student**](Student.md)| student object that needs to be added to the database | 

### Return type

[**models::Student**](Student.md)

### Authorization

[student_auth](../README.md#student_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
